IntentCodecLib

Struct IntentCodecLib 

pub struct IntentCodecLib { /* private fields */ }
Library that registers the Intent kind Shapes and codec:intent.

Implementations

Source

impl IntentCodecLib

pub fn new(codec_id: CodecId) -> Self

Build the lib with a freshly allocated codec id.